KeyEvent class

Constructors

KeyEvent(List<int> list)

Properties

dwExtraInfo ↔ int
getter/setter pair
flags ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isKeyDown → bool
no setter
isKeyUP → bool
no setter
isLeter → bool?
no setter
isNumber → bool?
no setter
isSysKey → bool
no setter
keyMsg ↔ KeyEventMsg
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanCode ↔ int
getter/setter pair
time ↔ int
getter/setter pair
vkCode ↔ int
getter/setter pair
vkName → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited