MethodChannelWinhooker class

Inheritance

Constructors

MethodChannelWinhooker()

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyBoardEventChannel ↔ EventChannel
getter/setter pair
keyboardState ↔ KeyBoardState
getter/setter pair
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
mouseEventChannel ↔ EventChannel
getter/setter pair
mouseState ↔ KeyBoardState
getter/setter pair
onKeyboardEvent ↔ StreamController
getter/setter pair
onMouseEvent ↔ StreamController
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelKeyboardListening() → dynamic
cancelMouseListening() → dynamic
getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startKeyboardWindowListening() → Future<void>
streamKeyboardEventFromNative() → Stream
override
streamMouseEventFromNative() → Stream
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

virtualKeyCode2StringMap ↔ Map<int, List<String>>?
getter/setter pair
virtualKeyString2CodeMap ↔ Map<String, int>?
getter/setter pair

Static Methods

isLeter(int vk) → bool?
isNumber(int vk) → bool?